/*
 * MCx8323_System.c
 *
 *  Created on: Nov 4, 2019

 */

#include <msp430.h>
#include "driverlib.h"
#include "Defines.h"
#include "Board.h"

#include "MCx8323_System.h"

void InitSystem(void)
{
    ErrorCount = 300;
    WDT_A_hold(WDT_A_BASE);
     clockValue = CS_getMCLK();

     // Configure Pins for XIN and XOUT
        //Set P2.6 and P2.7 as Module Function Input.
        GPIO_setAsPeripheralModuleFunctionInputPin(
            GPIO_PORT_P2,
            GPIO_PIN6 + GPIO_PIN7,
            GPIO_SECONDARY_MODULE_FUNCTION
        );

        //Initializes the XT1 and XT2 crystal frequencies being used
        CS_setExternalClockSource(
            4000000
            );

        //Initialize XT1. Returns STATUS_SUCCESS if initializes successfully
        CS_turnOnXT1HFWithTimeout(
                 CS_XT1_DRIVE_0,4000000,
            50000
            );
         CS_initClockSignal(CS_FLLREF, CS_XT1CLK_SELECT, CS_CLOCK_DIVIDER_1);




     //Set ACLK = REFOCLK with clock divider of 1
     CS_initClockSignal(CS_ACLK,CS_XT1CLK_SELECT,CS_CLOCK_DIVIDER_1);

     //Set MCLK = DCO with frequency divider of 1
     CS_initClockSignal(CS_MCLK,SELMS__DCOCLKDIV,CS_CLOCK_DIVIDER_1);

     //Set SMCLK = DCO with frequency divider of 1
     CS_initClockSignal(CS_SMCLK,SELMS__DCOCLKDIV,CS_CLOCK_DIVIDER_1);


     CS_initFLL(16000, 4);          // Clock program to 16MHz
     clockValue = CS_getMCLK();
     clockValue = CS_getSMCLK();



     //Configure UART pins
     GPIO_setAsPeripheralModuleFunctionInputPin(
         GPIO_PORT_UCA1TXD,
         GPIO_PIN_UCA1TXD,
         GPIO_FUNCTION_UCA1TXD
     );
     GPIO_setAsPeripheralModuleFunctionInputPin(
         GPIO_PORT_UCA1RXD,
         GPIO_PIN_UCA1RXD,
         GPIO_FUNCTION_UCA1RXD
     );

     /*
      * Disable the GPIO power-on default high-impedance mode to activate
      * previously configured port settings
      */
     PMM_unlockLPM5();


     //Configure UART
     //SMCLK = 16MHz, Baudrate = 9600
     //UCBRx = 104, UCBRFx = 2, UCBRSx = 0xD6, UCOS16 = 1 -> For 9600
     EUSCI_A_UART_initParam param_uart = {0};
     param_uart.selectClockSource = EUSCI_A_UART_CLOCKSOURCE_SMCLK;
     param_uart.clockPrescalar = 104;      //104;   //UCBRx = 6
     param_uart.firstModReg = 2;      //UCBRFx = 2
     param_uart.secondModReg = 0xD6;  //UCBRSx = 0xD6
     param_uart.parity = EUSCI_A_UART_NO_PARITY;
     param_uart.msborLsbFirst = EUSCI_A_UART_LSB_FIRST;
     param_uart.numberofStopBits = EUSCI_A_UART_ONE_STOP_BIT;
     param_uart.uartMode = EUSCI_A_UART_MODE;
     param_uart.overSampling = EUSCI_A_UART_OVERSAMPLING_BAUDRATE_GENERATION;

     if (STATUS_FAIL == EUSCI_A_UART_init(EUSCI_BASE, &param_uart)) {
         return;
     }

     EUSCI_A_UART_enable(EUSCI_BASE);

     EUSCI_A_UART_clearInterrupt(EUSCI_BASE,
         EUSCI_A_UART_RECEIVE_INTERRUPT);



     // Set P1.0 to output direction
        GPIO_setAsOutputPin(
            GPIO_PORT,
            GPIO_PIN
            );

        GPIO_setOutputLowOnPin(
            GPIO_PORT,
            GPIO_PIN
            );


        // Configure Pins for I2C
           GPIO_setAsPeripheralModuleFunctionInputPin(
               GPIO_PORT_UCB1SCL,
               GPIO_PIN_UCB1SCL,
               GPIO_FUNCTION_UCB1SCL
           );
           GPIO_setAsPeripheralModuleFunctionInputPin(
               GPIO_PORT_UCB1SDA,
               GPIO_PIN_UCB1SDA,
               GPIO_FUNCTION_UCB1SDA
           );

           /*
            * Disable the GPIO power-on default high-impedance mode to activate
            * previously configured port settings
            */
           PMM_unlockLPM5();

           EUSCI_B_I2C_initMasterParam param = {0};
           param.selectClockSource = EUSCI_B_I2C_CLOCKSOURCE_SMCLK;
           param.i2cClk = CS_getSMCLK();
           param.dataRate = EUSCI_B_I2C_SET_DATA_RATE_100KBPS;
           param.byteCounterThreshold = 0;
           param.autoSTOPGeneration = EUSCI_B_I2C_NO_AUTO_STOP;
           EUSCI_B_I2C_initMaster(EUSCI_I2C_BASE, &param);



           //Set Master in receive mode
           EUSCI_B_I2C_setMode(EUSCI_I2C_BASE,
                   EUSCI_B_I2C_TRANSMIT_MODE
                   );

           //Enable I2C Module to start operations
           EUSCI_B_I2C_enable(EUSCI_I2C_BASE);

           EUSCI_B_I2C_clearInterrupt(EUSCI_I2C_BASE,
                   EUSCI_B_I2C_TRANSMIT_INTERRUPT0 +
                   EUSCI_B_I2C_NAK_INTERRUPT
                   );
           //Enable master Receive interrupt
           EUSCI_B_I2C_enableInterrupt(EUSCI_I2C_BASE,
                   EUSCI_B_I2C_RECEIVE_INTERRUPT0 +
                   EUSCI_B_I2C_TRANSMIT_INTERRUPT0 +
                   EUSCI_B_I2C_NAK_INTERRUPT
                   );



           // Enable USCI_A0 RX interrupt
           EUSCI_A_UART_enableInterrupt(EUSCI_BASE,
               EUSCI_A_UART_RECEIVE_INTERRUPT);


}

